@@ -1,7 +1,7 @@
 # coding: utf-8
 
 # PYTHON IMPORTS
-import os, shutil, re, datetime, time
+import os, shutil, re, datetime, time, platform
 import mimetypes
 
 # DJANGO IMPORTS
@@ -82,9 +82,11 @@ class FileListing():
         if dirs:
             for d in dirs:
                 self._walk(os.path.join(path, d), filelisting)
+                filelisting.extend([path_strip(os.path.join(path,d), self.site.directory)])
 
-        filelisting.extend(dirs)
-        filelisting.extend(files)
+        if files:
+            for f in files:
+                filelisting.extend([path_strip(os.path.join(path,f), self.site.directory)])
 
     
     def walk(self):
@@ -189,7 +191,10 @@ class FileObject():
             from filebrowser.sites import site as default_site
             site = default_site
         self.site = site
-        self.path = path
+        if platform.system() == 'Windows':
+            self.path = path.replace('\\','/')
+        else:
+            self.path = path
         self.head = os.path.dirname(path)
         self.filename = os.path.basename(path)
         self.filename_lower = self.filename.lower()
@@ -378,11 +383,19 @@ class FileObject():
         return version_list
     
     def version_generate(self, version_suffix):
-        version_path = get_version_path(self.path, version_suffix, site=self.site)
+        path = self.path
+
+        if FORCE_PLACEHOLDER or (
+            SHOW_PLACEHOLDER and not self.site.storage.isfile(path)):
+            path = PLACEHOLDER
+        
+        version_path = get_version_path(path, version_suffix, site=self.site)
+
         if not self.site.storage.isfile(version_path):
-            version_path = version_generator(self.path, version_suffix, site=self.site)
-        elif self.site.storage.modified_time(self.path) > self.site.storage.modified_time(version_path):
-            version_path = version_generator(self.path, version_suffix, force=True, site=self.site)
+            version_path = version_generator(path, version_suffix, site=self.site)
+        elif self.site.storage.modified_time(path) > self.site.storage.modified_time(version_path):
+            version_path = version_generator(path, version_suffix, force=True, site=self.site)
+
         return FileObject(version_path, site=self.site)
     
     # FUNCTIONS
@@ -408,4 +421,3 @@ class FileObject():
             except:
                 pass
 
-
