@@ -124,7 +124,9 @@ class VersionObjectNode(Node):
             elif site.storage.modified_time(source) > site.storage.modified_time(version_path):
                 version_path = version_generator(source, version_prefix, force=True, site=site)
             context[self.var_name] = FileObject(version_path, site=site)
-        except:
+        except Exception as e:
+            if settings.TEMPLATE_DEBUG:
+                raise e
             context[self.var_name] = ""
         return ''
 
